"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hotModuleReplacement = exports.dispatchTopicMessage = exports.stopReadModelSubscriptionFailure = exports.stopReadModelSubscriptionSuccess = exports.stopReadModelSubscriptionRequest = exports.dropReadModelState = exports.applyReadModelDiff = exports.loadReadModelStateFailure = exports.loadReadModelStateSuccess = exports.loadReadModelStateRequest = exports.disconnectReadModel = exports.connectReadModel = exports.dropViewModelState = exports.loadViewModelStateFailure = exports.loadViewModelStateSuccess = exports.loadViewModelStateRequest = exports.disconnectViewModel = exports.connectViewModel = exports.unsubscribeTopicFailure = exports.unsubscribeTopicSuccess = exports.unsubscribeTopicRequest = exports.subscribeTopicFailure = exports.subscribeTopicSuccess = exports.subscribeTopicRequest = exports.sendCommandFailure = exports.sendCommandSuccess = exports.sendCommandRequest = void 0;

var _action_types = require("./action_types");

var sendCommandRequest = function sendCommandRequest(commandType, aggregateId, aggregateName, payload) {
  return {
    type: _action_types.SEND_COMMAND_REQUEST,
    commandType: commandType,
    aggregateId: aggregateId,
    aggregateName: aggregateName,
    payload: payload
  };
};

exports.sendCommandRequest = sendCommandRequest;

var sendCommandSuccess = function sendCommandSuccess(commandType, aggregateId, aggregateName, payload) {
  return {
    type: _action_types.SEND_COMMAND_SUCCESS,
    commandType: commandType,
    aggregateId: aggregateId,
    aggregateName: aggregateName,
    payload: payload
  };
};

exports.sendCommandSuccess = sendCommandSuccess;

var sendCommandFailure = function sendCommandFailure(commandType, aggregateId, aggregateName, payload, error) {
  return {
    type: _action_types.SEND_COMMAND_FAILURE,
    commandType: commandType,
    aggregateId: aggregateId,
    aggregateName: aggregateName,
    payload: payload,
    error: error
  };
};

exports.sendCommandFailure = sendCommandFailure;

var subscribeTopicRequest = function subscribeTopicRequest(topicName, topicId) {
  return {
    type: _action_types.SUBSCRIBE_TOPIC_REQUEST,
    topicName: topicName,
    topicId: topicId
  };
};

exports.subscribeTopicRequest = subscribeTopicRequest;

var subscribeTopicSuccess = function subscribeTopicSuccess(topicName, topicId) {
  return {
    type: _action_types.SUBSCRIBE_TOPIC_SUCCESS,
    topicName: topicName,
    topicId: topicId
  };
};

exports.subscribeTopicSuccess = subscribeTopicSuccess;

var subscribeTopicFailure = function subscribeTopicFailure(topicName, topicId, error) {
  return {
    type: _action_types.SUBSCRIBE_TOPIC_FAILURE,
    topicName: topicName,
    topicId: topicId,
    error: error
  };
};

exports.subscribeTopicFailure = subscribeTopicFailure;

var unsubscribeTopicRequest = function unsubscribeTopicRequest(topicName, topicId) {
  return {
    type: _action_types.UNSUBSCRIBE_TOPIC_REQUEST,
    topicName: topicName,
    topicId: topicId
  };
};

exports.unsubscribeTopicRequest = unsubscribeTopicRequest;

var unsubscribeTopicSuccess = function unsubscribeTopicSuccess(topicName, topicId) {
  return {
    type: _action_types.UNSUBSCRIBE_TOPIC_SUCCESS,
    topicName: topicName,
    topicId: topicId
  };
};

exports.unsubscribeTopicSuccess = unsubscribeTopicSuccess;

var unsubscribeTopicFailure = function unsubscribeTopicFailure(topicName, topicId, error) {
  return {
    type: _action_types.UNSUBSCRIBE_TOPIC_FAILURE,
    topicName: topicName,
    topicId: topicId,
    error: error
  };
};

exports.unsubscribeTopicFailure = unsubscribeTopicFailure;

var connectViewModel = function connectViewModel(viewModelName, aggregateIds, aggregateArgs) {
  return {
    type: _action_types.CONNECT_VIEWMODEL,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs
  };
};

exports.connectViewModel = connectViewModel;

var disconnectViewModel = function disconnectViewModel(viewModelName, aggregateIds, aggregateArgs) {
  return {
    type: _action_types.DISCONNECT_VIEWMODEL,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs
  };
};

exports.disconnectViewModel = disconnectViewModel;

var loadViewModelStateRequest = function loadViewModelStateRequest(viewModelName, aggregateIds, aggregateArgs) {
  return {
    type: _action_types.LOAD_VIEWMODEL_STATE_REQUEST,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs
  };
};

exports.loadViewModelStateRequest = loadViewModelStateRequest;

var loadViewModelStateSuccess = function loadViewModelStateSuccess(viewModelName, aggregateIds, aggregateArgs, state, aggregateVersionsMap) {
  return {
    type: _action_types.LOAD_VIEWMODEL_STATE_SUCCESS,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs,
    state: state,
    aggregateVersionsMap: aggregateVersionsMap
  };
};

exports.loadViewModelStateSuccess = loadViewModelStateSuccess;

var loadViewModelStateFailure = function loadViewModelStateFailure(viewModelName, aggregateIds, aggregateArgs, error) {
  return {
    type: _action_types.LOAD_VIEWMODEL_STATE_FAILURE,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs,
    error: error
  };
};

exports.loadViewModelStateFailure = loadViewModelStateFailure;

var dropViewModelState = function dropViewModelState(viewModelName, aggregateIds, aggregateArgs) {
  return {
    type: _action_types.DROP_VIEWMODEL_STATE,
    viewModelName: viewModelName,
    aggregateIds: aggregateIds,
    aggregateArgs: aggregateArgs
  };
};

exports.dropViewModelState = dropViewModelState;

var connectReadModel = function connectReadModel(readModelName, resolverName, resolverArgs, isReactive) {
  return {
    type: _action_types.CONNECT_READMODEL,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    isReactive: isReactive
  };
};

exports.connectReadModel = connectReadModel;

var disconnectReadModel = function disconnectReadModel(readModelName, resolverName, resolverArgs, isReactive) {
  return {
    type: _action_types.DISCONNECT_READMODEL,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    isReactive: isReactive
  };
};

exports.disconnectReadModel = disconnectReadModel;

var loadReadModelStateRequest = function loadReadModelStateRequest(readModelName, resolverName, resolverArgs, isReactive, queryId) {
  return {
    type: _action_types.LOAD_READMODEL_STATE_REQUEST,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    isReactive: isReactive,
    queryId: queryId
  };
};

exports.loadReadModelStateRequest = loadReadModelStateRequest;

var loadReadModelStateSuccess = function loadReadModelStateSuccess(readModelName, resolverName, resolverArgs, isReactive, queryId, result, timeToLive) {
  return {
    type: _action_types.LOAD_READMODEL_STATE_SUCCESS,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    isReactive: isReactive,
    queryId: queryId,
    result: result,
    timeToLive: timeToLive
  };
};

exports.loadReadModelStateSuccess = loadReadModelStateSuccess;

var loadReadModelStateFailure = function loadReadModelStateFailure(readModelName, resolverName, resolverArgs, isReactive, queryId, error) {
  return {
    type: _action_types.LOAD_READMODEL_STATE_FAILURE,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    isReactive: isReactive,
    queryId: queryId,
    error: error
  };
};

exports.loadReadModelStateFailure = loadReadModelStateFailure;

var applyReadModelDiff = function applyReadModelDiff(readModelName, resolverName, resolverArgs, diff) {
  return {
    type: _action_types.APPLY_READMODEL_DIFF,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs,
    diff: diff
  };
};

exports.applyReadModelDiff = applyReadModelDiff;

var dropReadModelState = function dropReadModelState(readModelName, resolverName, resolverArgs) {
  return {
    type: _action_types.DROP_READMODEL_STATE,
    readModelName: readModelName,
    resolverName: resolverName,
    resolverArgs: resolverArgs
  };
};

exports.dropReadModelState = dropReadModelState;

var stopReadModelSubscriptionRequest = function stopReadModelSubscriptionRequest(readModelName, resolverName, queryId) {
  return {
    type: _action_types.STOP_READ_MODEL_SUBSCRIPTION_REQUEST,
    readModelName: readModelName,
    resolverName: resolverName,
    queryId: queryId
  };
};

exports.stopReadModelSubscriptionRequest = stopReadModelSubscriptionRequest;

var stopReadModelSubscriptionSuccess = function stopReadModelSubscriptionSuccess(readModelName, resolverName, queryId) {
  return {
    type: _action_types.STOP_READ_MODEL_SUBSCRIPTION_SUCCESS,
    readModelName: readModelName,
    resolverName: resolverName,
    queryId: queryId
  };
};

exports.stopReadModelSubscriptionSuccess = stopReadModelSubscriptionSuccess;

var stopReadModelSubscriptionFailure = function stopReadModelSubscriptionFailure(readModelName, resolverName, queryId, error) {
  return {
    type: _action_types.STOP_READ_MODEL_SUBSCRIPTION_FAILURE,
    readModelName: readModelName,
    resolverName: resolverName,
    queryId: queryId,
    error: error
  };
};

exports.stopReadModelSubscriptionFailure = stopReadModelSubscriptionFailure;

var dispatchTopicMessage = function dispatchTopicMessage(message) {
  return {
    type: _action_types.DISPATCH_TOPIC_MESSAGE,
    message: message
  };
};

exports.dispatchTopicMessage = dispatchTopicMessage;

var hotModuleReplacement = function hotModuleReplacement(hotModuleReplacementId) {
  return {
    type: _action_types.HOT_MODULE_REPLACEMENT,
    hotModuleReplacementId: hotModuleReplacementId
  };
};

exports.hotModuleReplacement = hotModuleReplacement;
//# sourceMappingURL=actions.js.map