"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _effects = require("redux-saga/effects");

var _reduxSaga = require("redux-saga");

var _uuid = _interopRequireDefault(require("uuid"));

var _get_hash = _interopRequireDefault(require("./get_hash"));

var _diff_listener_saga = _interopRequireDefault(require("./diff_listener_saga"));

var _unsubscribe_read_model_topics_saga = _interopRequireDefault(require("./unsubscribe_read_model_topics_saga"));

var _actions = require("./actions");

var _action_types = require("./action_types");

var _constants = require("./constants");

var _create_api = require("./create_api");

/*
  Saga is launched on action `CONNECT_READMODEL`, emitted by read model connector.
  If read model with supposed options had already been fetched, do nothing.
  Saga performs resolver result fetching and subscribes to diff topic.
  If read model is reactive, it launches `diff_listener_saga`.
  Saga ends when resolver result is fetched and diff topic is acknowledged.
  Resolver result is fetched by `load_read_model_state_saga`, interaction
  performs through following actions: `LOAD_READMODEL_STATE_REQUEST`,
  `LOAD_READMODEL_STATE_SUCCESS` and `LOAD_READMODEL_STATE_FAILURE`.
  Subscription to diff topic is performed by `subscribe_saga`, interaction
  performs by following actions: `SUBSCRIBE_TOPIC_REQUEST`,
  `SUBSCRIBE_TOPIC_SUCCESS` and `SUBSCRIBE_TOPIC_FAILURE`.
  If read model is reactive, saga suspends itself after `timeToLive` ms
  and emits new `CONNECT_READMODEL` action to reconnect.
*/
var connectReadModelSaga =
/*#__PURE__*/
_regenerator.default.mark(function connectReadModelSaga(sagaArgs, action) {
  var connectionManager, sagaManager, sagaKey, queryIdMap, sessionId, store, readModelName, resolverName, resolverArgs, isReactive, skipConnectionManager, _connectionManager$ad, addedConnections, key, queryId, subscribeResultAction, _loop2, _ret;

  return _regenerator.default.wrap(function connectReadModelSaga$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          connectionManager = sagaArgs.connectionManager, sagaManager = sagaArgs.sagaManager, sagaKey = sagaArgs.sagaKey, queryIdMap = sagaArgs.queryIdMap, sessionId = sagaArgs.sessionId, store = sagaArgs.store;
          readModelName = action.readModelName, resolverName = action.resolverName, resolverArgs = action.resolverArgs, isReactive = action.isReactive, skipConnectionManager = action.skipConnectionManager;

          if (skipConnectionManager) {
            _context3.next = 6;
            break;
          }

          _connectionManager$ad = connectionManager.addConnection({
            connectionName: readModelName,
            connectionId: "".concat((0, _get_hash.default)(action.resolverName)).concat((0, _get_hash.default)(action.resolverArgs))
          }), addedConnections = _connectionManager$ad.addedConnections;

          if (!(addedConnections.length !== 1)) {
            _context3.next = 6;
            break;
          }

          return _context3.abrupt("return");

        case 6:
          return _context3.delegateYield(sagaManager.stop("".concat(_action_types.DISCONNECT_READMODEL).concat(sagaKey)), "t0", 7);

        case 7:
          key = "".concat(readModelName).concat((0, _get_hash.default)(action.resolverName)).concat((0, _get_hash.default)(action.resolverArgs));

          if (!queryIdMap.has(key)) {
            queryIdMap.set(key, 0);
          }

          queryIdMap.set(key, queryIdMap.get(key) + 1);
          queryId = (0, _uuid.default)("".concat(key).concat(queryIdMap.get(key)).concat(sessionId), _constants.namespace);

          if (!isReactive) {
            _context3.next = 23;
            break;
          }

          return _context3.delegateYield(sagaManager.start("".concat(_action_types.CONNECT_READMODEL).concat(sagaKey), _diff_listener_saga.default, (0, _objectSpread2.default)({}, sagaArgs, {
            queryId: queryId
          }), action), "t1", 13);

        case 13:
          if (!true) {
            _context3.next = 23;
            break;
          }

          _context3.next = 16;
          return (0, _effects.put)((0, _actions.subscribeTopicRequest)(_constants.diffTopicName, queryId));

        case 16:
          _context3.next = 18;
          return (0, _effects.take)(function (action) {
            return (action.type === _action_types.SUBSCRIBE_TOPIC_SUCCESS || action.type === _action_types.SUBSCRIBE_TOPIC_FAILURE) && _constants.diffTopicName === action.topicName && queryId === action.topicId;
          });

        case 18:
          subscribeResultAction = _context3.sent;

          if (!(subscribeResultAction.type === _action_types.SUBSCRIBE_TOPIC_SUCCESS)) {
            _context3.next = 21;
            break;
          }

          return _context3.abrupt("break", 23);

        case 21:
          _context3.next = 13;
          break;

        case 23:
          _loop2 =
          /*#__PURE__*/
          _regenerator.default.mark(function _loop2() {
            var loadReadModelStateResultAction;
            return _regenerator.default.wrap(function _loop2$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return (0, _effects.put)((0, _actions.loadReadModelStateRequest)(readModelName, resolverName, resolverArgs, isReactive, queryId));

                  case 2:
                    _context2.next = 4;
                    return (0, _effects.take)(function (action) {
                      return (action.type === _action_types.LOAD_READMODEL_STATE_SUCCESS || action.type === _action_types.LOAD_READMODEL_STATE_FAILURE) && action.queryId === queryId;
                    });

                  case 4:
                    loadReadModelStateResultAction = _context2.sent;

                    if (!(loadReadModelStateResultAction.type === _action_types.LOAD_READMODEL_STATE_SUCCESS)) {
                      _context2.next = 9;
                      break;
                    }

                    _context2.next = 8;
                    return (0, _effects.fork)(
                    /*#__PURE__*/
                    _regenerator.default.mark(function _callee() {
                      return _regenerator.default.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              _context.next = 2;
                              return (0, _reduxSaga.delay)(loadReadModelStateResultAction.timeToLive);

                            case 2:
                              return _context.delegateYield((0, _unsubscribe_read_model_topics_saga.default)({
                                queryId: queryId
                              }), "t0", 3);

                            case 3:
                              return _context.delegateYield(sagaManager.stop("".concat(_action_types.CONNECT_READMODEL).concat(sagaKey), function () {
                                return store.dispatch((0, _objectSpread2.default)({}, action, {
                                  skipConnectionManager: true
                                }));
                              }), "t1", 4);

                            case 4:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, this);
                    }));

                  case 8:
                    return _context2.abrupt("return", "break");

                  case 9:
                    if (!(loadReadModelStateResultAction.type === _action_types.LOAD_READMODEL_STATE_FAILURE && loadReadModelStateResultAction.error instanceof _create_api.HttpError)) {
                      _context2.next = 12;
                      break;
                    }

                    // eslint-disable-next-line no-console
                    console.warn('Http error: ', loadReadModelStateResultAction.error);
                    return _context2.abrupt("return", {
                      v: void 0
                    });

                  case 12:
                    _context2.next = 14;
                    return (0, _reduxSaga.delay)(500);

                  case 14:
                  case "end":
                    return _context2.stop();
                }
              }
            }, _loop2, this);
          });

        case 24:
          if (!true) {
            _context3.next = 35;
            break;
          }

          return _context3.delegateYield(_loop2(), "t2", 26);

        case 26:
          _ret = _context3.t2;
          _context3.t3 = _ret;
          _context3.next = _context3.t3 === "break" ? 30 : 31;
          break;

        case 30:
          return _context3.abrupt("break", 35);

        case 31:
          if (!((0, _typeof2.default)(_ret) === "object")) {
            _context3.next = 33;
            break;
          }

          return _context3.abrupt("return", _ret.v);

        case 33:
          _context3.next = 24;
          break;

        case 35:
        case "end":
          return _context3.stop();
      }
    }
  }, connectReadModelSaga, this);
});

var _default = connectReadModelSaga;
exports.default = _default;
//# sourceMappingURL=connect_read_model_saga.js.map