"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _getIterator2 = _interopRequireDefault(require("@babel/runtime/core-js/get-iterator"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _keys = _interopRequireDefault(require("@babel/runtime/core-js/object/keys"));

var _effects = require("redux-saga/effects");

var _reduxSaga = require("redux-saga");

var _get_hash = _interopRequireDefault(require("./get_hash"));

var _event_listener_saga = _interopRequireDefault(require("./event_listener_saga"));

var _actions = require("./actions");

var _action_types = require("./action_types");

var _create_api = require("./create_api");

/*
  Saga is launched on action `CONNECT_VIEWMODEL`, emitted by view model connector.
  If view model with supposed options had already been fetched, do nothing.
  Saga performs view model state fetching and subscribe to topics Array<{aggregateId, eventType}>
  If launches `event_listener_saga`.
  Saga ends when view model state is fetched and all necessary topics are acknowledged.
  View model state is fetched by `load_view_model_state_saga`, interaction
  performs through following actions: `LOAD_VIEWMODEL_STATE_REQUEST`,
  `LOAD_VIEWMODEL_STATE_SUCCESS` and `LOAD_VIEWMODEL_STATE_FAILURE`.
  Subscription to necessary topics are performed by `subscribe_saga`, interaction
  performs by following actions: `SUBSCRIBE_TOPIC_REQUEST`,
  `SUBSCRIBE_TOPIC_SUCCESS` and `SUBSCRIBE_TOPIC_FAILURE`.
*/
var connectViewModelSaga =
/*#__PURE__*/
_regenerator.default.mark(function connectViewModelSaga(sagaArgs, action) {
  var viewModels, connectionManager, sagaManager, sagaKey, skipConnectionManager, viewModelName, aggregateIds, aggregateArgs, connectionId, _connectionManager$ad, addedConnections, viewModel, eventTypes, subscriptionKeys, counter, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, _ref3, aggregateId, eventType, _loop, loadViewModelStateResultAction;

  return _regenerator.default.wrap(function connectViewModelSaga$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          viewModels = sagaArgs.viewModels, connectionManager = sagaArgs.connectionManager, sagaManager = sagaArgs.sagaManager, sagaKey = sagaArgs.sagaKey, skipConnectionManager = sagaArgs.skipConnectionManager;
          viewModelName = action.viewModelName, aggregateIds = action.aggregateIds, aggregateArgs = action.aggregateArgs;
          connectionId = "".concat((0, _get_hash.default)(action.aggregateIds)).concat((0, _get_hash.default)(action.aggregateArgs));

          if (skipConnectionManager) {
            _context2.next = 7;
            break;
          }

          _connectionManager$ad = connectionManager.addConnection({
            connectionName: viewModelName,
            connectionId: connectionId
          }), addedConnections = _connectionManager$ad.addedConnections;

          if (!(addedConnections.length !== 1)) {
            _context2.next = 7;
            break;
          }

          return _context2.abrupt("return");

        case 7:
          return _context2.delegateYield(sagaManager.stop("".concat(_action_types.DISCONNECT_VIEWMODEL).concat(sagaKey)), "t0", 8);

        case 8:
          viewModel = viewModels.find(function (_ref) {
            var name = _ref.name;
            return name === viewModelName;
          });
          eventTypes = (0, _keys.default)(viewModel.projection).filter(function (eventType) {
            return eventType !== 'Init';
          }); // viewModelName + aggregateIds => Array<{ aggregateId, eventType }>

          subscriptionKeys = eventTypes.reduce(function (acc, eventType) {
            if (Array.isArray(aggregateIds)) {
              acc.push.apply(acc, (0, _toConsumableArray2.default)(aggregateIds.map(function (aggregateId) {
                return {
                  aggregateId: aggregateId,
                  eventType: eventType
                };
              })));
            } else if (aggregateIds === '*') {
              acc.push({
                aggregateId: '*',
                eventType: eventType
              });
            }

            return acc;
          }, []);
          return _context2.delegateYield(sagaManager.start("".concat(_action_types.CONNECT_VIEWMODEL).concat(sagaKey), _event_listener_saga.default, (0, _objectSpread2.default)({}, sagaArgs, {
            eventTypes: eventTypes
          }), action), "t1", 12);

        case 12:
          if (!(subscriptionKeys.length > 0)) {
            _context2.next = 48;
            break;
          }

          counter = subscriptionKeys.length;
          _iteratorNormalCompletion = true;
          _didIteratorError = false;
          _iteratorError = undefined;
          _context2.prev = 17;
          _iterator = (0, _getIterator2.default)(subscriptionKeys);

        case 19:
          if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
            _context2.next = 27;
            break;
          }

          _ref3 = _step.value;
          aggregateId = _ref3.aggregateId, eventType = _ref3.eventType;
          _context2.next = 24;
          return (0, _effects.put)((0, _actions.subscribeTopicRequest)(eventType, aggregateId));

        case 24:
          _iteratorNormalCompletion = true;
          _context2.next = 19;
          break;

        case 27:
          _context2.next = 33;
          break;

        case 29:
          _context2.prev = 29;
          _context2.t2 = _context2["catch"](17);
          _didIteratorError = true;
          _iteratorError = _context2.t2;

        case 33:
          _context2.prev = 33;
          _context2.prev = 34;

          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }

        case 36:
          _context2.prev = 36;

          if (!_didIteratorError) {
            _context2.next = 39;
            break;
          }

          throw _iteratorError;

        case 39:
          return _context2.finish(36);

        case 40:
          return _context2.finish(33);

        case 41:
          _loop =
          /*#__PURE__*/
          _regenerator.default.mark(function _loop() {
            var subscribeResultAction;
            return _regenerator.default.wrap(function _loop$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    _context.next = 2;
                    return (0, _effects.take)(function (action) {
                      return (action.type === _action_types.SUBSCRIBE_TOPIC_SUCCESS || action.type === _action_types.SUBSCRIBE_TOPIC_FAILURE) && subscriptionKeys.find(function (key) {
                        return key.aggregateId === action.topicId && key.eventType === action.topicName;
                      });
                    });

                  case 2:
                    subscribeResultAction = _context.sent;

                    if (subscribeResultAction.type === _action_types.SUBSCRIBE_TOPIC_SUCCESS) {
                      subscriptionKeys = subscriptionKeys.filter(function (key) {
                        return !(key.aggregateId === subscribeResultAction.topicId && key.eventType === subscribeResultAction.topicName);
                      });
                    }

                    counter--;

                  case 5:
                  case "end":
                    return _context.stop();
                }
              }
            }, _loop, this);
          });

        case 42:
          if (!(counter > 0)) {
            _context2.next = 46;
            break;
          }

          return _context2.delegateYield(_loop(), "t3", 44);

        case 44:
          _context2.next = 42;
          break;

        case 46:
          _context2.next = 12;
          break;

        case 48:
          if (!true) {
            _context2.next = 63;
            break;
          }

          _context2.next = 51;
          return (0, _effects.put)((0, _actions.loadViewModelStateRequest)(viewModelName, aggregateIds, aggregateArgs));

        case 51:
          _context2.next = 53;
          return (0, _effects.take)(function (action) {
            return (action.type === _action_types.LOAD_VIEWMODEL_STATE_SUCCESS || action.type === _action_types.LOAD_VIEWMODEL_STATE_FAILURE) && action.viewModelName === viewModelName && "".concat((0, _get_hash.default)(action.aggregateIds)).concat((0, _get_hash.default)(action.aggregateArgs)) === connectionId;
          });

        case 53:
          loadViewModelStateResultAction = _context2.sent;

          if (!(loadViewModelStateResultAction.type === _action_types.LOAD_VIEWMODEL_STATE_SUCCESS)) {
            _context2.next = 56;
            break;
          }

          return _context2.abrupt("break", 63);

        case 56:
          if (!(loadViewModelStateResultAction.type === _action_types.LOAD_VIEWMODEL_STATE_FAILURE && loadViewModelStateResultAction.error instanceof _create_api.HttpError)) {
            _context2.next = 59;
            break;
          }

          // eslint-disable-next-line no-console
          console.warn('Http error: ', loadViewModelStateResultAction.error);
          return _context2.abrupt("return");

        case 59:
          _context2.next = 61;
          return (0, _reduxSaga.delay)(500);

        case 61:
          _context2.next = 48;
          break;

        case 63:
        case "end":
          return _context2.stop();
      }
    }
  }, connectViewModelSaga, this, [[17, 29, 33, 41], [34,, 36, 40]]);
});

var _default = connectViewModelSaga;
exports.default = _default;
//# sourceMappingURL=connect_view_model_saga.js.map